SharedBytesAllocationController

Struct SharedBytesAllocationController 

pub struct SharedBytesAllocationController { /* private fields */ }
Available on crate feature serde only.
Allocation controller backed by bytes::Bytes for zero-copy access.

This enables zero-copy tensor loading by referencing data directly from the source buffer without copying into heap-allocated memory.

Notes

  • Read access via memory() is zero-copy as long as no mutable access has been requested.
  • Mutable access via memory_mut() triggers a copy of the data into heap memory (copy-on-write semantics), behind a Once so the copy happens exactly once even under concurrent access.
  • The underlying bytes::Bytes remains valid for the lifetime of this controller. This is ensured by bytes::Bytes using reference counting internally.

Implementations

Source

impl SharedBytesAllocationController

pub fn new( bytes: Bytes, property: AllocationProperty, ) -> SharedBytesAllocationController

Create a new controller from a bytes::Bytes buffer with a specific allocation property.

The allocation property is used by GPU backends to optimize data transfers:

Example
use cubecl_common::bytes::{SharedBytesAllocationController, AllocationProperty};

// From static data (zero-copy, no heap allocation)
let static_bytes = bytes::Bytes::from_static(&[1, 2, 3, 4]);
let controller = SharedBytesAllocationController::new(static_bytes, AllocationProperty::Other);

// Memory-mapped file data - use File property for optimized GPU transfers
let mmap_bytes = bytes::Bytes::from_static(&[1, 2, 3, 4]); // pretend this is mmap
let controller = SharedBytesAllocationController::new(mmap_bytes, AllocationProperty::File);