AutodiffLogLevel

Enum AutodiffLogLevel 

pub enum AutodiffLogLevel {
    Disabled,
    Basic,
    Medium,
    Full,
}
Log levels for autodiff logging.

Variants



Disabled

Autodiff logging is disabled.



Basic

Log backward graph size and the checkpoint strategy applied per forward pass.



Medium

Additionally log each tensor that gets checkpointed or recomputed.



Full

Log every graph node traversal and recomputation event.