log_autodiff

Function log_autodiff 

pub fn log_autodiff<F>(level: AutodiffLogLevel, f: F)
where F: FnOnce() -> String,
Emit an autodiff log message when the configured level is at least level.

The message is only constructed when logging is enabled.