Module data

Module data 

Tensor data representation and helpers.

Structs

TensorData
Data structure for tensors.
Tolerance
The tolerance used to compare to floating point numbers.

Enums

DataError
The things that can go wrong when manipulating tensor data.