pub enum DataError {
StorageAccess(AccessError),
InvalidRepresentation(CheckedCastError),
DTypeMismatch {
expected: DType,
actual: DType,
},
UnsupportedConversion {
from: DType,
to: DType,
},
ElementCountMismatch {
expected: usize,
actual: usize,
},
}Expand description
Errors that can occur while accessing or converting TensorData.
Variants
StorageAccess(AccessError)
Host access to the underlying storage failed.
InvalidRepresentation(CheckedCastError)
The stored bytes aren’t a valid representation of the requested element type.
DTypeMismatch
The stored dtype doesn’t match the requested dtype.
UnsupportedConversion
Unsupported data conversion.
ElementCountMismatch
The byte storage doesn’t match the number of elements described by the shape.