TensorData

Struct TensorData 

pub struct TensorData {
    pub bytes: Bytes,
    pub shape: Shape,
    pub dtype: DType,
}
Data structure for tensors.

Fields

bytes: Bytes

The values of the tensor (as bytes).

shape: Shape

The shape of the tensor.

dtype: DType

The data type of the tensor.

Implementations

Source

impl TensorData

pub fn assert_eq(&self, other: &Self, strict: bool)

Asserts the data is equal to another data.

Arguments
  • other - The other data.
  • strict - If true, the data types must the be same. Otherwise, the comparison is done in the current data type.
Panics

Panics if the data is not equal.

pub fn assert_approx_eq<F: Float + Element>( &self, other: &Self, tolerance: Tolerance<F>, )

Asserts the data is approximately equal to another data.

Arguments
  • other - The other data.
  • tolerance - The tolerance of the comparison.
Panics

Panics if the data is not approximately equal.

pub fn assert_within_range<E: ElementOrdered>(&self, range: Range<E>)

Asserts each value is within a given range.

Arguments
  • range - The range.
Panics

If any value is not within the half-open range bounded inclusively below and exclusively above (start..end).

pub fn assert_within_range_inclusive<E: ElementOrdered>( &self, range: RangeInclusive<E>, )

Asserts each value is within a given inclusive range.

Arguments
  • range - The range.
Panics

If any value is not within the half-open range bounded inclusively (start..=end).

Source

impl TensorData

pub fn new<E: Element, S: Into<Shape>>(value: Vec<E>, shape: S) -> Self

Creates a new tensor data structure.

pub fn quantized<E: Element, S: Into<Shape>>( value: Vec<E>, shape: S, scheme: QuantScheme, qparams: &[f32], global: Option<f32>, ) -> Self

Creates a new quantized tensor data structure.

pub fn from_bytes<S: Into<Shape>>(bytes: Bytes, shape: S, dtype: DType) -> Self

Creates a new tensor data structure from raw bytes.

pub fn from_bytes_vec<S: Into<Shape>>( bytes: Vec<u8>, shape: S, dtype: DType, ) -> Self

Creates a new tensor data structure from raw bytes stored in a vector.

Prefer TensorData::new or TensorData::quantized over this method unless you are certain that the byte representation is valid.

pub fn as_slice<E: Element>(&self) -> Result<&[E], DataError>

Returns the immutable slice view of the tensor data.

This materializes lazy storage into host-accessible memory when necessary.

Errors

Returns an error if host access fails, the target element type doesn’t match the stored type, or the stored byte representation is invalid for E.

pub fn as_mut_slice<E: Element>(&mut self) -> Result<&mut [E], DataError>

Returns the mutable slice view of the tensor data.

This materializes lazy storage and performs copy-on-write when necessary.

Errors

Returns an error if host access fails, the target element type doesn’t match the stored type, or the stored byte representation is invalid for E.

pub fn rank(&self) -> usize

Returns the rank (the number of dimensions).

pub fn num_elements(&self) -> usize

Returns the total number of elements of the tensor data.

pub fn random<E: Element, R: Rng, S: Into<Shape>>( shape: S, distribution: Distribution, rng: &mut R, ) -> Self

Populates the data with random values.

pub fn zeros<E: Element, S: Into<Shape>>(shape: S) -> TensorData

Populates the data with zeros.

pub fn ones<E: Element, S: Into<Shape>>(shape: S) -> TensorData

Populates the data with ones.

pub fn full<E: Element, S: Into<Shape>>(shape: S, fill_value: E) -> TensorData

Populates the data with the given value

pub fn full_dtype<E: Into<Scalar>, S: Into<Shape>>( shape: S, fill_value: E, dtype: DType, ) -> TensorData

Populates the data with the given value

pub fn as_bytes(&self) -> &[u8]

Returns the data as a slice of bytes.

pub fn into_bytes(self) -> Bytes

Returns the bytes representation of the data.

Source

impl TensorData

pub fn try_to_vec_as<E: Element>(&self) -> Result<Vec<E>, DataError>

Copies and converts the data to a Vec<E>.

By contract, this is equivalent to: data.clone().try_into_vec_as::<E>()

Particular conversions may provide more efficient implementations.

Errors

Returns an error if storage access fails, the conversion isn’t supported, or the stored representation or element count is invalid.

pub fn try_into_vec_as<E: Element>(self) -> Result<Vec<E>, DataError>

Converts the data to a Vec<E>.

By contract, this is equivalent to: data.try_cast_as::<E>()?.try_into_vec::<E>()

Particular conversions may provide more efficient implementations.

Errors

Returns an error if storage access fails, the conversion isn’t supported, or the stored representation or element count is invalid.

pub fn to_vec<E: Element>(&self) -> Result<Vec<E>, DataError>

👎Deprecated since 0.22.0:

use try_to_vec::<E>()

Copies the stored values to a vector without dtype conversion.

pub fn into_vec<E: Element>(self) -> Result<Vec<E>, DataError>

👎Deprecated since 0.22.0:

use try_into_vec::<E>()

Converts the stored values into a vector without dtype conversion.

pub fn try_to_vec<E: Element>(&self) -> Result<Vec<E>, DataError>

Copies the stored values to a vector without dtype conversion.

Errors

Returns an error if storage access fails, the stored dtype doesn’t match E, or the byte representation is invalid for E.

pub fn try_into_vec<E: Element>(self) -> Result<Vec<E>, DataError>

Converts the stored values into a vector without dtype conversion.

This may reuse the underlying allocation when its layout and ownership permit it.

Errors

Returns an error if storage access fails, the stored dtype doesn’t match E, or the byte representation is invalid for E.

pub fn iter<E: Element>(&self) -> Box<dyn Iterator<Item = E> + '_>

Returns an iterator over the values of the tensor data.

pub fn convert<E: Element>(self) -> Self

Converts the data to the dtype represented by E.

Panics

Panics if storage access fails, the conversion isn’t supported, or the stored representation or element count is invalid.

pub fn convert_dtype(self, dtype: DType) -> Self

Converts the data to dtype.

Panics

Panics if storage access fails, the conversion isn’t supported, or the stored representation or element count is invalid.

pub fn try_cast_as<E: Element>(self) -> Result<TensorData, DataError>

Converts the data to the dtype represented by E.

By contract, this is equivalent to: data.try_cast(E::dtype())

Errors

Returns an error if storage access fails, the conversion isn’t supported, or the stored representation or element count is invalid.

pub fn try_cast(self, dtype: DType) -> Result<TensorData, DataError>

Converts the data to dtype.

Errors

Returns an error if storage access fails, the conversion isn’t supported, or the stored representation or element count is invalid.

Source

impl TensorData

pub fn try_view<E: Element>(&self) -> Result<TensorDataView<'_, E>, DataError>

Returns an Index view wrapper of the TensorData.

Example
use burn_std::*;

let data = TensorData::from([[1.0, 2.0], [3.0, 4.0]]);
let shape = data.shape.clone();
let view: TensorDataView<f64> = data.try_view().unwrap();

assert_eq!(view[&[0, 0]], 1.0);
assert_eq!(view[&[0, 1]], 2.0);
assert_eq!(view[&[1, 0]], 3.0);
assert_eq!(view[&[1, 1]], 4.0);
Errors

Returns an error if storage access fails or the dtype, byte representation, or element count is incompatible with the requested view.

pub fn view<E: Element>(&self) -> TensorDataView<'_, E>

Returns a TensorDataView<E> of the TensorData.

Example
use burn_std::*;

let data = TensorData::from([[1.0, 2.0], [3.0, 4.0]]);
let shape = data.shape.clone();
let view: TensorDataView<f64> = data.view();

assert_eq!(view[&[0, 0]], 1.0);
assert_eq!(view[&[0, 1]], 2.0);
assert_eq!(view[&[1, 0]], 3.0);
assert_eq!(view[&[1, 1]], 4.0);
Returns

The view.

Panics

Panics if the view can’t be created because storage access fails or the dtype, byte representation, or element count is incompatible with E.

pub fn try_mut_view<E: Element>( &mut self, ) -> Result<TensorDataViewMut<'_, E>, DataError>

Returns a TensorDataViewMut<E> of the TensorData.

Example
use burn_std::*;

let mut data = TensorData::from([[1.0, 2.0], [3.0, 4.0]]);
let shape = data.shape.clone();
let mut view: TensorDataViewMut<f64> = data.try_mut_view().unwrap();

assert_eq!(view[&[0, 0]], 1.0);
assert_eq!(view[&[0, 1]], 2.0);
assert_eq!(view[&[1, 0]], 3.0);
assert_eq!(view[&[1, 1]], 4.0);

view[&[0, 0]] = 10.0;
assert_eq!(view[&[0, 0]], 10.0);
Errors

Returns an error if storage access fails or the dtype, byte representation, or element count is incompatible with the requested view.

pub fn mut_view<E: Element>(&mut self) -> TensorDataViewMut<'_, E>

Returns a TensorDataViewMut<E> of the TensorData.

Example
use burn_std::*;

let mut data = TensorData::from([[1.0, 2.0], [3.0, 4.0]]);
let shape = data.shape.clone();
let mut view: TensorDataViewMut<f64> = data.mut_view();

assert_eq!(view[&[0, 0]], 1.0);
assert_eq!(view[&[0, 1]], 2.0);
assert_eq!(view[&[1, 0]], 3.0);
assert_eq!(view[&[1, 1]], 4.0);

view[&[0, 0]] = 10.0;
assert_eq!(view[&[0, 0]], 10.0);
Returns

The mut view.

Panics

Panics if the view can’t be created because storage access fails or the dtype, byte representation, or element count is incompatible with E.