TensorDataViewMut

Struct TensorDataViewMut 

pub struct TensorDataViewMut<'a, E: Element> { /* private fields */ }
Typed mutable IndexMut view over a TensorData.

Creating a mutable view materializes lazy storage and performs copy-on-write when necessary. It does not perform dtype conversion.

Example

use burn_std::*;

let mut data = TensorData::from([[1.0, 2.0], [3.0, 4.0]]);
let shape = data.shape.clone();
let dtype = data.dtype;
let mut view: TensorDataViewMut<f64> = data.mut_view();

assert_eq!(view.shape(), &shape);
assert_eq!(&view.dtype(), &dtype);

assert_eq!(view[&[0, 0]], 1.0);
assert_eq!(view[&[0, 1]], 2.0);
assert_eq!(view[&[1, 0]], 3.0);
assert_eq!(view[&[1, 1]], 4.0);

view[&[0, 0]] = 10.0;
assert_eq!(view[&[0, 0]], 10.0);

Implementations

Source

impl<'a, E: Element> TensorDataViewMut<'a, E>

pub fn try_mut_view( data: &'a mut TensorData, ) -> Result<TensorDataViewMut<'a, E>, DataError>

Creates a typed mutable indexed view over data.

Example
use burn_std::*;

let mut data = TensorData::from([[1.0, 2.0], [3.0, 4.0]]);
let shape = data.shape.clone();
let dtype = data.dtype;

let mut view: TensorDataViewMut<f64> =
    TensorDataViewMut::try_mut_view(&mut data).unwrap();

assert_eq!(view.shape(), &shape);
assert_eq!(&view.dtype(), &dtype);

assert_eq!(view[&[0, 0]], 1.0);
assert_eq!(view[&[0, 1]], 2.0);
assert_eq!(view[&[1, 0]], 3.0);
assert_eq!(view[&[1, 1]], 4.0);

view[&[0, 0]] = 10.0;
assert_eq!(view[&[0, 0]], 10.0);
Errors

Returns an error if storage access fails or the dtype, byte representation, or element count is incompatible with E.

pub fn shape(&self) -> &Shape

Returns the shape of the view.

pub fn dtype(&self) -> DType

Returns the dtype of the view.

pub fn ravel_index<I: AsIndex>(&self, index: &[I]) -> usize

Ravels the dims via ravel_index and the view’s shape.