Module distribution

Module distribution 

Random value distributions. Random value distributions used to initialize and populate tensor data.

Structs

DistributionSampler
Distribution sampler for random value of a tensor.

Enums

Distribution
Distribution for random value of a tensor.
DistributionSamplerKind
Distribution sampler kind for random value of a tensor.