Module element

Module element 

Traits for tensor element types and conversions. Traits and helpers for working with element types and conversions.

Modules

cast
Tensor element casting.

Macros

make_element
Macro to implement the element trait for a type.

Enums

Scalar
A scalar element.

Traits

Element
Core element trait for tensor values.
ElementComparison
Element ordering trait.
ElementConversion
Element conversion trait for tensor.
ElementEq
Element trait for equality of a tensor.
ElementLimits
Element limits trait.
ElementOrdered
Ordered element trait for tensor values.
ElementRandom
Element trait for random value of a tensor.