pub struct StrideRecord {
pub shape: Shape,
pub strides: Strides,
}Expand description
Collected shape/stride record.
As this is used for error messages, there is no expectation that this is valid, or that the ranks match.
Fields
shape: Shapestrides: StridesImplementations
Sourceimpl StrideRecord
impl StrideRecord
Sourcepub fn from_usize_strides(shape: &[usize], strides: &[usize]) -> StrideRecord
pub fn from_usize_strides(shape: &[usize], strides: &[usize]) -> StrideRecord
Create a new StrideRecord from a slice of usize strides.
Sourcepub fn from_isize_strides(shape: &[usize], strides: &[isize]) -> StrideRecord
pub fn from_isize_strides(shape: &[usize], strides: &[isize]) -> StrideRecord
Create a new StrideRecord from a slice of isize strides.