Format utilities.
Structs
- Debug
Raw - Print string without quotes
Functions
- format_
debug - Format a debug type.
- format_
str - Format strings for use in identifiers and types.
- type_
name_ sanitized - Provide a long, sanitized type name for use in context identifiers
- type_
name_ short_ sanitized - Provide a short, sanitized type name for use in function or file names