pub struct ConvOptions<const N: usize> {
pub stride: [usize; N],
pub padding: [(usize, usize); N],
pub dilation: [usize; N],
pub groups: usize,
}Expand description
Convolution options.
Fields
stride: [usize; N]Stride (non-zero).
padding: [(usize, usize); N]Padding as (begin, end) pairs for each spatial dimension.
dilation: [usize; N]Dilation (non-zero).
groups: usizeGroups (non-zero).
Implementations
Sourceimpl<const N: usize> ConvOptions<N>
impl<const N: usize> ConvOptions<N>
Sourcepub fn new(
stride: [usize; N],
padding: [usize; N],
dilation: [usize; N],
groups: usize,
) -> Self
pub fn new( stride: [usize; N], padding: [usize; N], dilation: [usize; N], groups: usize, ) -> Self
Constructs a new ConvOptions.
Sourcepub fn new_with_padding(
stride: [usize; N],
padding: [(usize, usize); N],
dilation: [usize; N],
groups: usize,
) -> Self
pub fn new_with_padding( stride: [usize; N], padding: [(usize, usize); N], dilation: [usize; N], groups: usize, ) -> Self
Constructs convolution options with explicit per-side padding.
Sourcepub fn is_asymmetric(&self) -> bool
pub fn is_asymmetric(&self) -> bool
Returns true if padding is asymmetric.
Sourcepub fn padding_begin(&self) -> [usize; N]
pub fn padding_begin(&self) -> [usize; N]
Returns the padding at the beginning of every spatial dimension.
Sourcepub fn padding_end(&self) -> [usize; N]
pub fn padding_end(&self) -> [usize; N]
Returns the padding at the end of every spatial dimension.
Sourcepub fn symmetric_padding(&self) -> [usize; N]
pub fn symmetric_padding(&self) -> [usize; N]