pub fn runtime_kind() -> RuntimeKindExpand description
Return the currently declared kind of runtime the host program runs on.
Defaults to RuntimeKind::Sync until set_runtime_kind is called.
pub fn runtime_kind() -> RuntimeKindReturn the currently declared kind of runtime the host program runs on.
Defaults to RuntimeKind::Sync until set_runtime_kind is called.