set_runtime_kind

Function set_runtime_kind 

pub fn set_runtime_kind(kind: RuntimeKind)
Declare the kind of runtime the host program is running on.

Intended to be called once near program start (e.g. when a remote server declares that it hosts the backend on an async runtime). Backends read it via runtime_kind.