pub struct TensorContainer<ID> { /* private fields */ }Expand description
Contains tensor of arbitrary dimension.
Implementations
Sourceimpl<ID> TensorContainer<ID>
impl<ID> TensorContainer<ID>
Sourcepub fn get<T: Clone + Send + 'static>(&self, id: &ID) -> Option<T>
pub fn get<T: Clone + Send + 'static>(&self, id: &ID) -> Option<T>
Get a tensor with the given ID.
Sourcepub fn get_mut_ref<T: Clone + Send + 'static>(
&mut self,
id: &ID,
) -> Option<&mut T>
pub fn get_mut_ref<T: Clone + Send + 'static>( &mut self, id: &ID, ) -> Option<&mut T>
Get a mutable reference to the tensor with the given ID.
Sourcepub fn register<T: Clone + Send + 'static>(&mut self, id: ID, value: T)
pub fn register<T: Clone + Send + 'static>(&mut self, id: ID, value: T)
Register a new tensor for the given ID.
Notes
If a tensor is already registered for the given ID, it will be replaced.