pub fn params_shape(data_shape: &Shape, scheme: &QuantScheme) -> ShapeExpand description
Calculate the shape of the block scale grid for a given tensor and scheme.
A two-level scheme’s per-tensor scale is not part of this grid.
pub fn params_shape(data_shape: &Shape, scheme: &QuantScheme) -> ShapeCalculate the shape of the block scale grid for a given tensor and scheme.
A two-level scheme’s per-tensor scale is not part of this grid.