Module shape

Module shape 

Tensor shape utilities. Tensor shape definition.

Macros

shape

Structs

Shape
Reexport to avoid annoying rust-analyzer bug where it imports the module instead of the macro Shape of a tensor.
SmallVec
Reexport for use in macros A Vec-like container that can store a small number of elements inline.

Enums

ExpressionError
Common Expression Error.
MetadataError
Reexport to avoid annoying rust-analyzer bug where it imports the module instead of the macro Error that can occur when attempting to modify shapes.

Traits

SliceOps
Slice-related ops on Shape

Functions

calculate_matmul_output
Reexport to avoid annoying rust-analyzer bug where it imports the module instead of the macro Compute the output shape for matrix multiplication with broadcasting support.