MetadataError

Enum MetadataError 

pub enum MetadataError {
    RankMismatch {
        left: usize,
        right: usize,
    },
    IncompatibleDims {
        left: usize,
        right: usize,
        dim: usize,
    },
    OutOfBounds {
        dim: usize,
        rank: usize,
    },
    IncompatibleShapes {
        left: Shape,
        right: Shape,
    },
    Invalid {
        reason: String,
    },
}
Error that can occur when attempting to modify shapes.

Variants



RankMismatch

The operands have different ranks.

Fields

left: usize
right: usize


IncompatibleDims

A pair of dimensions are incompatible for broadcasting.

Fields

left: usize
right: usize
dim: usize


OutOfBounds

Invalid dimension specified for the rank.

Fields

dim: usize
rank: usize


IncompatibleShapes

A pair of shapes are incompatible for the operation.

Fields

left: Shape
right: Shape


Invalid

Invalid shape.

Fields

reason: String