Burn Standard Library
This library contains core types and utilities shared across Burn, including shapes, indexing, and data types.
Re-exports
pub use tensor::*;pub use data::*;pub use distribution::*;pub use element::*;pub use runtime_kind::*;pub use ops::*;
Modules
- arena
std - A circular, allocation-free arena for reusable memory blocks.
- backtrace
- Backtrace module to build error reports.
- benchmark
- Module for benchmark timings
- bytes
serde - Utilities module to manipulate bytes.
- config
- Burn runtime configurations.
- data
- Tensor data representation and helpers.
- device
- Device module.
- device_
handle - Device handle module.
- distributed
- Distributed configurations.
- distribution
- Random value distributions. Random value distributions used to initialize and populate tensor data.
- element
- Traits for tensor element types and conversions. Traits and helpers for working with element types and conversions.
- errors
- Common Errors.
- format
- Format utilities.
- future
- Future utils with a compatible API for native, non-std and wasm environments.
- id
- Id module contains types for unique identifiers.
- ops
- Configuration types for tensor operations (conv, pool, interpolate, pad, etc). Configuration types for tensor operations.
- pool
- A dynamically-growing pool that leases exclusive, reusable single-cell items. A dynamically-growing pool of single-cell items handed out as exclusive, non-cloneable handles.
- profile
- Module for profiling any executable part
- quant
- Quantization primitives required outside of
cubecl-quant - rand
- Rand module contains types for random number generation for non-std environments and for std environments.
- reader
- Useful when you need to read async data without having to decorate each function with async notation.
- runtime_
kind - Runtime kind of the host program (async / sync / no-std). Runtime kind of the host program.
- stream_
id - Stream id related utilities.
- stub
- Stub module contains types for stubs for non-std environments and for std environments.
- tensor
- Tensor utilities.
Macros
- make_
element - Macro to implement the element trait for a type.
- obfuscate
- Generate a type-erased, inline wrapper for a single value.
- s
- Slice argument constructor for tensor indexing.
Structs
- Access
Policy - What an access is allowed to do to satisfy a read/write of a
Bytes. - Bytes
- A buffer similar to
Box<[u8]>that supports custom memory alignment and allows trailing uninitialized bytes. - Communication
Id - An ID unique to any unordered combination of devices, used by collective / communication primitives (distributed training etc.).
- Device
Handle - TODO: Docs
- Device
Settings - Settings controlling the default data types for a specific device.
- Reader
- Configures a read of a
Bytes. - Shared
Allocation Controller - Allocation controller that shares a view into another
Bytesbehind anArc. - Shared
Bytes Allocation Controller - Allocation controller backed by
bytes::Bytesfor zero-copy access. - Stride
Record - Common Errors. Collected shape/stride record.
- Writer
- Configures a mutable access of a
Bytes. - bf16
- A 16-bit floating point type implementing the
bfloat16format. - e2m3
- A 6-bit floating point type with 2 exponent bits and 3 mantissa bits.
- e3m2
- A 6-bit floating point type with 3 exponent bits and 2 mantissa bits.
- f16
- A 16-bit floating point type implementing the IEEE 754-2008 standard
binary16a.k.a “half” format. - flex32
- A floating point type with relaxed precision, minimum
f16, maxf32. - tf32
- A 19-bit floating point type implementing the
tfloat32format.
Enums
- Access
Error - Error returned when accessing a
Bytes. - Allocation
Error - Errors that may occur during memory allocation operations.
- Allocation
Property - The kind of allocation behind the Bytes type.
- Bounds
Error - Common Errors. Access Bounds Error.
- Device
Error - Errors returned by device-related operations.
- Execution
Error - An error that can happen when syncing a device.
- Expression
Error - Common Errors. Common Expression Error.
- Index
Kind - Common Errors. Describes the kind of an index.
- Split
Error - Error when splitting an allocation.
- Split
Policy - Controls how
Bytes::splitbehaves when the allocation can’t be split in place. - Stride
Error - Common Errors. Error describing striding issues.
- View
Error - Error when taking a view into an allocation.
Traits
- Allocation
Controller - Defines how an
Allocationcan be controlled.