Burn runtime configurations.
Modules
Structs
- Burn
Config - Represents the global configuration for Burn.
- Logger
- Central logging utility for Burn, managing one sink registry shared across subsystems.
- Logger
Config - Configuration for a log sink, parameterized by a subsystem-specific log level.
- Logger
Sinks - Registry of log sinks, deduplicating by output target so that multiple subsystems can share a single file or stdout/stderr stream.
Enums
- LogCrate
Level - Log levels forwarded to the
logcrate.
Traits
- LogLevel
- Trait for types usable as a subsystem-specific log level.
- Runtime
Config - Trait for runtime configurations potentially loaded from a TOML file.
Functions
- config
- Returns the current
BurnConfig, cached in thread-local storage on native targets. - log_
autodiff - Emit an autodiff log message when the configured level is at least
level. - log_
fusion - Emit a fusion log message when the configured level is at least
level.