Tensor data representation and helpers.
Structs
- Tensor
Data - Data structure for tensors.
- Tolerance
- The tolerance used to compare to floating point numbers.
Enums
- Data
Error - The things that can go wrong when manipulating tensor data.