Tensor utilities.
Re-exports
pub use dtype::*;pub use quantization::*;pub use shape::*;pub use slice::*;
Modules
- dtype
- Tensor data type.
- indexing
- Indexing Utilities
- quantization
- Quantization data representation.
- shape
- Tensor shape definition.
- slice
- Tensor slice utilities.
Macros
Structs
Enums
- Reshape
Action - The action to take for a reshape operation.
- Reshape
Analysis - The reshape kind.
Traits
- AsIndex
- Helper trait for implementing indexing with support for negative indices.
- AsSize
- Types which can be converted to a
usizeSize.
Functions
- broadcast_
strides - Calculate the new strides given added batch dimensions.
- contiguous_
strides - Computes the strides for a contiguous tensor with the given shape.
- is_
contiguous - Check if the current tensor is contiguous.
- ravel_
index - Compute the ravel index for the given coordinates.
- reshape_
action - Returns the proper action to take when reshaping a tensor.
- reshape_
analysis - Returns the analysis of a reshape operation.
- split_
strides - Calculate the new strides given added split dimensions.
- wrap_
index - Wraps a dimension index to be within the bounds of the dimension size.