Tensor shape utilities. Tensor shape definition.
Macros
Structs
- Shape
- Reexport to avoid annoying rust-analyzer bug where it imports the module instead of the macro Shape of a tensor.
- Small
Vec - Reexport for use in macros
A
Vec-like container that can store a small number of elements inline.
Enums
- Expression
Error - Common Expression Error.
- Metadata
Error - Reexport to avoid annoying rust-analyzer bug where it imports the module instead of the macro Error that can occur when attempting to modify shapes.
Traits
Functions
- calculate_
matmul_ output - Reexport to avoid annoying rust-analyzer bug where it imports the module instead of the macro Compute the output shape for matrix multiplication with broadcasting support.