Module shape

Module shape 

Tensor shape definition.

Macros

shape

Structs

Shape
Shape of a tensor.

Enums

ExpressionError
Common Expression Error.
MetadataError
Error that can occur when attempting to modify shapes.

Traits

SliceOps
Slice-related ops on Shape

Functions

calculate_matmul_output
Compute the output shape for matrix multiplication with broadcasting support.