pub struct Metadata {
pub shape: Shape,
pub strides: Strides,
}Fields
shape: Shapestrides: StridesImplementations
Sourceimpl Metadata
impl Metadata
pub fn new(shape: impl Into<Shape>, strides: impl Into<Strides>) -> Metadata
pub fn shape(&self) -> &Shape
pub fn shape_mut(&mut self) -> &mut Shape
pub fn strides(&self) -> &Strides
pub fn strides_mut(&mut self) -> &mut Strides
pub fn rank(&self) -> usize
pub fn num_dims(&self) -> usize
Sourcepub fn num_elements(&self) -> usize
pub fn num_elements(&self) -> usize
Returns the total number of elements of a tensor having this shape
pub fn swapped(self, dim0: usize, dim1: usize) -> Metadata
pub fn swap(&mut self, dim0: usize, dim1: usize)
Sourcepub fn permute(&mut self, axes: &[usize]) -> Result<(), MetadataError>
pub fn permute(&mut self, axes: &[usize]) -> Result<(), MetadataError>
Reorder the shape dimensions according to the permutation of axes.
pub fn permuted(self, axes: &[usize]) -> Result<Metadata, MetadataError>
Sourcepub fn insert(&mut self, index: usize, shape: usize, stride: usize)
pub fn insert(&mut self, index: usize, shape: usize, stride: usize)
Insert a dimension of shape with stride at position index.